@@ -170,6 +170,11 @@ def init():
                 response = requests.get('http://35.225.89.124/push_commit')
                 res=response.content
                 print(res)
+                index=res.index("'")
+                index1=res.index("'",index+1)
+                res=res[index:index1]
+                val=len(res)
+                print(val)
                 val=len(res)
                 print(val)
                 # data=str(res)
@@ -179,7 +184,7 @@ def init():
                 # index2 = data.index("\n",index1+1)
                 # repoN = data[index1 + 1:index2]
                 # print("repo name is ",repoN)
-                if val >0:
+                if val >0 and res==repo_name:
                     repo = git.Repo(path)
                     origin = repo.remote(name='origin')
                     res=origin.pull()
@@ -203,6 +208,9 @@ def init():
                 response = requests.get('http://35.225.89.124/push_commit')
                 res=response.content
                 print(res)
+                index=res.index("'")
+                index1=res.index("'",index+1)
+                res=res[index:index1]
                 val=len(res)
                 print(val)
                 # data=str(res)
@@ -212,7 +220,7 @@ def init():
                 # index2 = data.index("\n",index1+1)
                 # repoN = data[index1 + 1:index2]
                 # print("repo name is ",repoN)
-                if val >0:
+                if val >0 and res==repo_name:
                     repo = git.Repo(path)
                     origin = repo.remote(name='origin')
                     res=origin.pull()
